@@ -46,7 +46,7 @@ class EYAMLProcessor(Processor):
 
         Raises:  N/A
         """
-        self.eyaml: Optional[str] = kwargs.pop("binary", "eyaml")
+        self.eyaml: str = str(kwargs.pop("binary", "eyaml"))
         self.publickey: Optional[str] = kwargs.pop("publickey", None)
         self.privatekey: Optional[str] = kwargs.pop("privatekey", None)
         super().__init__(logger, data)
@@ -131,18 +131,22 @@ class EYAMLProcessor(Processor):
         if not self._can_run_eyaml():
             raise EYAMLCommandException("No accessible eyaml command.")
 
-        cmdstr: str = "{} decrypt --quiet --stdin".format(self.eyaml)
+        cmd: List[str] = [
+            self.eyaml,
+            'decrypt',
+            '--quiet',
+            '--stdin'
+        ]
         if self.publickey:
-            cmdstr += " --pkcs7-public-key={}".format(self.publickey)
+            cmd.append(f"--pkcs7-public-key={self.publickey}")
         if self.privatekey:
-            cmdstr += " --pkcs7-private-key={}".format(self.privatekey)
+            cmd.append(f"--pkcs7-private-key={self.privatekey}")
 
-        cmd: List[str] = cmdstr.split()
         cleanval: str = str(value).replace("\n", "").replace(" ", "").rstrip()
         bval: bytes = cleanval.encode("ascii")
         self.logger.debug(
-            "EYAMLPath::decrypt_eyaml:  About to execute {} against:\n{}"
-            .format(cmdstr, cleanval)
+            f"About to execute {' '.join(cmd)} against:\n{cleanval}",
+            prefix="EYAMLPath::decrypt_eyaml:  "
         )
 
         try:
@@ -157,19 +161,19 @@ class EYAMLProcessor(Processor):
             ).stdout.decode('ascii').rstrip()
         except CalledProcessError as ex:
             raise EYAMLCommandException(
-                "The {} command cannot be run due to exit code:  {}"
-                .format(self.eyaml, ex.returncode)
+                f"The {self.eyaml} command cannot be run due to exit code:"
+                f"  {ex.returncode}"
             ) from ex
 
         # Check for bad decryptions
         self.logger.debug(
-            "EYAMLPath::decrypt_eyaml:  Decrypted result:  {}".format(retval)
+            f"EYAMLPath::decrypt_eyaml:  Decrypted result:  {retval}"
         )
         if not retval or retval == cleanval:
             raise EYAMLCommandException(
                 "Unable to decrypt value!  Please verify you are using the"
-                + " correct old EYAML keys and the value is not corrupt:  {}"
-                .format(cleanval)
+                " correct old EYAML keys and the value is not corrupt:"
+                "    {cleanval}"
             )
 
         return retval
@@ -196,20 +200,23 @@ class EYAMLProcessor(Processor):
 
         if not self._can_run_eyaml():
             raise EYAMLCommandException(
-                "The eyaml binary is not executable at {}.".format(self.eyaml)
+                f"The eyaml binary is not executable at:  {self.eyaml}"
             )
 
-        cmdstr: str = ("{} encrypt --quiet --stdin --output={}"
-                       .format(self.eyaml, output))
+        cmd: List[str] = [
+            self.eyaml,
+            'encrypt',
+            '--quiet',
+            '--stdin',
+            f"--output={output}"
+        ]
         if self.publickey:
-            cmdstr += " --pkcs7-public-key={}".format(self.publickey)
+            cmd.append(f"--pkcs7-public-key={self.publickey}")
         if self.privatekey:
-            cmdstr += " --pkcs7-private-key={}".format(self.privatekey)
+            cmd.append(f"--pkcs7-private-key={self.privatekey}")
 
-        cmd: List[str] = cmdstr.split()
         self.logger.debug(
-            "EYAMLPath::encrypt_eyaml:  About to execute:  {}"
-            .format(" ".join(cmd))
+            f"EYAMLPath::encrypt_eyaml:  About to execute:  {' '.join(cmd)}"
         )
         bval: bytes = value.encode("ascii")
 
@@ -219,13 +226,13 @@ class EYAMLProcessor(Processor):
             retval: str = (
                 run(cmd, stdout=PIPE, input=bval, check=True, shell=False)
                 .stdout
-                .decode('ascii')
+                .decode("ascii")
                 .rstrip()
             )
         except CalledProcessError as ex:
             raise EYAMLCommandException(
-                "The {} command cannot be run due to exit code:  {}"
-                .format(self.eyaml, ex.returncode)
+                f"The {self.eyaml} command cannot be run due to exit code:"
+                f"  {ex.returncode}"
             ) from ex
 
         # While exceedingly rare and difficult to test for, it is possible
@@ -234,16 +241,17 @@ class EYAMLProcessor(Processor):
         # that works multi-platform.  So, ignore covering this case.
         if not retval: # pragma: no cover
             raise EYAMLCommandException(
-                ("The {} command was unable to encrypt your value.  Please"
-                 + " verify this process can run that command and read your"
-                 + " EYAML keys.").format(self.eyaml)
+                f"The {self.eyaml} command was unable to encrypt your value."
+                "  Please verify this process can run that command and read"
+                " your EYAML keys."
             )
 
         if output is EYAMLOutputFormats.BLOCK:
             retval = re.sub(r" +", "", retval) + "\n"
 
         self.logger.debug(
-            "EYAMLPath::encrypt_eyaml:  Encrypted result:\n{}".format(retval)
+            f"Encrypted result:\n{retval}",
+            prefix="EYAMLPath::encrypt_eyaml:  "
         )
         return retval
 
@@ -269,8 +277,7 @@ class EYAMLProcessor(Processor):
         - `YAMLPathException` when YAML Path is invalid
         """
         self.logger.verbose(
-            "Encrypting value(s) for {}."
-            .format(yaml_path)
+            f"Encrypting value(s) for {yaml_path} using {output} format."
         )
         encval: str = self.encrypt_eyaml(value, output)
         emit_format: YAMLValueFormats = YAMLValueFormats.FOLDED
@@ -306,9 +313,7 @@ class EYAMLProcessor(Processor):
         Raises:
         - `YAMLPathException` when YAML Path is invalid
         """
-        self.logger.verbose(
-            "Decrypting value(s) at {}.".format(yaml_path)
-        )
+        self.logger.verbose(f"Decrypting value(s) at {yaml_path}.")
         for node in self.get_nodes(yaml_path, mustexist=mustexist,
                                    default_value=default_value):
             plain_text: str = self.decrypt_eyaml(node.node)
